==> flutter_fast_forms-0.5.0.tar.gz: lib/src/switch/switch.dart <==
import 'package:flutter/material.dart';

import '../form_field.dart';
import '../form_theme.dart';

typedef SwitchTitleBuilder = Widget Function(FastSwitchState state);

@immutable
class FastSwitch extends FastFormField<bool> {
  FastSwitch({
    bool autofocus = false,
    AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction,
    FormFieldBuilder<bool> builder,
    EdgeInsetsGeometry contentPadding =
        const EdgeInsets.symmetric(horizontal: 16.0),
    InputDecoration decoration,
    bool enabled = true,
    String helper,
    @required String id,
    bool initialValue,
    Key key,
    String label,
    ValueChanged<bool> onChanged,
    VoidCallback onReset,
    FormFieldSetter<bool> onSaved,
    @required this.title,
    SwitchTitleBuilder titleBuilder,
    FormFieldValidator<bool> validator,
  }) : super(
          autofocus: autofocus,
          autovalidateMode: autovalidateMode,
          builder: builder ??
              (field) {
                final state = field as FastSwitchState;
                final theme = Theme.of(state.context);
                final formTheme = FastFormTheme.of(state.context);
                final _decoration = decoration ??
                    formTheme.getInputDecoration(state.context, state.widget) ??
                    const InputDecoration();
                final InputDecoration effectiveDecoration =
                    _decoration.applyDefaults(theme.inputDecorationTheme);
                final _titleBuilder = titleBuilder ?? switchTitleBuilder;
                return InputDecorator(
                  decoration: effectiveDecoration.copyWith(
                    errorText: state.errorText,
                  ),
                  child: SwitchListTile.adaptive(
                    autofocus: autofocus,
                    contentPadding: contentPadding,
                    onChanged: enabled ? state.didChange : null,
                    selected: state.value,
                    title: title is String ? _titleBuilder(state) : null,
                    value: state.value,
                  ),
                );
              },
          decoration: decoration,
          enabled: enabled,
          helper: helper,
          id: id,
          initialValue: initialValue ?? false,
          key: key,
          label: label,
          onChanged: onChanged,
          onReset: onReset,
          onSaved: onSaved,
          validator: validator,
        );

  final String title;

  @override
  FastSwitchState createState() => FastSwitchState();
}

class FastSwitchState extends FastFormFieldState<bool> {
  @override
  FastSwitch get widget => super.widget as FastSwitch;
}

final SwitchTitleBuilder switchTitleBuilder = (FastSwitchState state) {
  return Text(
    state.widget.title,
    style: TextStyle(
      fontSize: 14.0,
      color: state.value ? Colors.black : Colors.grey,
    ),
  );
};

==> flutter_fast_forms-0.6.0.tar.gz: lib/src/switch/switch.dart <==
import 'package:flutter/material.dart';

import '../form_field.dart';
import '../form_scope.dart';

typedef SwitchTitleBuilder = Widget Function(FastSwitchState state);

@immutable
class FastSwitch extends FastFormField<bool> {
  FastSwitch({
    bool autofocus = false,
    AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction,
    FormFieldBuilder<bool> builder,
    EdgeInsetsGeometry contentPadding =
        const EdgeInsets.symmetric(horizontal: 16.0),
    InputDecoration decoration,
    bool enabled = true,
    String helper,
    @required String id,
    bool initialValue,
    Key key,
    String label,
    ValueChanged<bool> onChanged,
    VoidCallback onReset,
    FormFieldSetter<bool> onSaved,
    @required this.title,
    SwitchTitleBuilder titleBuilder,
    FormFieldValidator<bool> validator,
  }) : super(
          autofocus: autofocus,
          autovalidateMode: autovalidateMode,
          builder: builder ??
              (field) {
                final state = field as FastSwitchState;
                final theme = Theme.of(state.context);
                final decorator =
                    FastFormScope.of(state.context).inputDecorator;
                final _decoration = decoration ??
                    decorator(state.context, state.widget) ??
                    const InputDecoration();
                final InputDecoration effectiveDecoration =
                    _decoration.applyDefaults(theme.inputDecorationTheme);
                final _titleBuilder = titleBuilder ?? switchTitleBuilder;
                return InputDecorator(
                  decoration: effectiveDecoration.copyWith(
                    errorText: state.errorText,
                  ),
                  child: SwitchListTile.adaptive(
                    autofocus: autofocus,
                    contentPadding: contentPadding,
                    onChanged: enabled ? state.didChange : null,
                    selected: state.value,
                    title: title is String ? _titleBuilder(state) : null,
                    value: state.value,
                  ),
                );
              },
          decoration: decoration,
          enabled: enabled,
          helper: helper,
          id: id,
          initialValue: initialValue ?? false,
          key: key,
          label: label,
          onChanged: onChanged,
          onReset: onReset,
          onSaved: onSaved,
          validator: validator,
        );

  final String title;

  @override
  FastSwitchState createState() => FastSwitchState();
}

class FastSwitchState extends FastFormFieldState<bool> {
  @override
  FastSwitch get widget => super.widget as FastSwitch;
}

final SwitchTitleBuilder switchTitleBuilder = (FastSwitchState state) {
  return Text(
    state.widget.title,
    style: TextStyle(
      fontSize: 14.0,
      color: state.value ? Colors.black : Colors.grey,
    ),
  );
};
